Summary:	Hierarchical Data Format Library
Name:		HDF
Version:	4.2r0
Release:	9.PU_IAS.2
License:	BSD-like (see COPYING)
Group:		Scientific/Development
Source:		ftp://hdf.ncsa.uiuc.edu/HDF/HDF/HDF_Current/%{name}%{version}.tar.gz
Source1:	%{name}%{version}-docs.tar.gz
Patch1:		HDF-fix-stupid-cpp.patch
Patch2:		HDF-bigendian.patch.bz2
Patch3:		HDF-ppc.patch.bz2
Patch4:		HDF-ia64.patch.bz2
Patch5:		HDF4-errno.patch
URL:		http://hdf.ncsa.uiuc.edu
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root
BuildRequires:	byacc flex gcc-g77 groff
Provides:	HDF-devel

%description
HDF is a multi-object file format that facilitates the transfer of various
types of scientific data between machines and operating systems. 
HDF allows self-definitions of data content and easy extensibility for
future enhancements or compatibility with other standard formats.
HDF includes Fortran and C calling interfaces, and utilities to
prepare raw image of data files or for use with other NCSA software.

The HDF library contains interfaces for storing and retrieving compressed or
uncompressed 8-bit and 24=bit raster images with palettes,
n-Dimensional scientific datasets and binary tables. AN interface is also
included that allows arbitrary grouping of other HDF objects.

%package util
Summary:	HDF utilities and test data files
Group:		Scientific/Applications

%description util
This package contains utilities for HDF data manipulation and
test data files.

%package doc
Summary:        Documentation for Hierarchical Data Format Library
Group:          Scientific/Documentation

%description doc
This package contains documentation for Hierarchical Data 
Format Library.

%prep
%setup -q -n %{name}%{version} -a 1
%patch1 -p1
%ifarch ppc
%patch2 -p1 -b .bigend
%patch3 -p1 -b .ppc
%endif
%ifarch ia64
%patch4 -p1 -b .ia64
%endif
#%patch5 -p1

%build
%ifarch ia64
export RPM_OPT_FLAGS="$RPM_OPT_FLAGS -fPIC"
%endif
CFLAGS="$RPM_OPT_FLAGS -DHAVE_NETCDF" CXXFLAGS="$RPM_OPT_FLAGS" \
%ifarch ppc
	./configure --prefix=%{_prefix} i386-unknown-linux
%else
	./configure --prefix=%{_prefix} --with-szlib
%endif
make CFLAGS="$RPM_OPT_FLAGS -ansi -D_BSD_SOURCE -DHAVE_NETCDF" FFLAGS="$RPM_OPT_FLAGS" LIBSX="-lm"

# make tests (is ia64 broken?)
%ifnarch ia64
make CFLAGS="$RPM_OPT_FLAGS -ansi -D_BSD_SOURCE -DHAVE_NETCDF" FFLAGS="$RPM_OPT_FLAGS" LIBSX="-lm" check
%endif
mkdir -p samples
cp -a hdf/util/testfiles/* samples


%install
rm -rf $RPM_BUILD_ROOT
%makeinstall
# remove files already provided by other packages (libjpeg, netcdf, zlib)
rm -f $RPM_BUILD_ROOT%{_includedir}/{jconfig.h,jerror.h,jmorecfg.h,jpeglib.h} \
    $RPM_BUILD_ROOT%{_includedir}/{zconf.h,zlib.h} \
    $RPM_BUILD_ROOT%{_bindir}/{ncdump,ncgen} \
    $RPM_BUILD_ROOT%{_includedir}/netcdf.{h,inc,f90}
mv -f $RPM_BUILD_ROOT%{_bindir}/vmake $RPM_BUILD_ROOT%{_bindir}/vmake-hdf
mkdir -p $RPM_BUILD_ROOT%{_datadir}/hdf
cp -aR samples $RPM_BUILD_ROOT%{_datadir}/hdf/

#stuff we don't need but bothers rpm 4.1
rm -f $RPM_BUILD_ROOT%{_libdir}/{libjpeg.a,libz.a}
rm -f $RPM_BUILD_ROOT/usr/man/man1/*

# we do not want these man pages, they are already in netcdf
rm -f $RPM_BUILD_ROOT%{_mandir}/man1/ncdump* $RPM_BUILD_ROOT%{_mandir}/man1/ncgen*

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(-,root,root)
%doc COPYING README
%{_libdir}/libdf.a
%{_libdir}/libmfhdf.a
%{_libdir}/libudport.a
%{_includedir}/*
%{_mandir}/*/*

%files util
%defattr(-,root,root)
%doc COPYING README
%dir %{_datadir}/hdf
%dir %{_datadir}/hdf/samples
%{_bindir}/*
%attr(644,root,root) %{_datadir}/hdf/samples/*

%files doc
%defattr(-,root,root)
%doc HDF*/*pdf

%changelog
* Thu May 01 2003 Josko Plazonic <plazonic@math.princeton.edu>
- rebuild for 9 PU_IAS

* Fri Jul 05 2002 Josko Plazonic <plazonic@math.princeton.edu>
- rebuild for 7.3 PU_IAS

* Sun Sep 09 2001 Stefan van der Eijk <stefan@eijk.nu> 4.1r4-9mdk
- BuildRequires: flex groff

* Tue Jun 26 2001 Matthias Badaire <mbadaire@mandrakesoft.com> 4.1r4-8mdk
- fix ia64 config file : replace f90 with g77

* Mon Jun 25 2001 Giusepp Ghib <ghibo@mandrakesoft.com> 4.1r4-7mdk
- added gcc-g77 in BuildRequires (thanks Jeff).
 
* Sat Jun 23 2001 Giuseppe Ghib <ghibo@mandrakesoft.com> 4.1r4-6mdk
- added attempt patch for PPC (bigendian) arch.

* Mon May 21 2001 Jeff Garzik <jgarzik@mandrakesoft.com> 4.1r4-5mdk
- BuildRequires: byacc
- fix rpmlint warnings

* Sun May 13 2001 Stefan van der Eijk <stefan@eijk.nu> 4.1r4-4mdk
- pass same CFLAGS and FFLAGS to make test

* Fri Apr 20 2001 Francis Galiegue <fg@mandrakesoft.com> 4.1r4-3mdk
- Add -fPIC to CFLAGS...
- Patch1: fix braindead cpp directives.
- Don't run make test on ia64 :(

* Wed Jan 03 2001 David BAUDENS <baudens@mandrakesoft.com> 4.1r4-2mdk
- ExcludeArch: ppc.

* Tue Dec 26 2000 Giuseppe Ghibb <ghibo@mandrakesoft.com> 4.1r4-1mdk
- initial release for OpenDX building.
